struct BrowserResponse(SendWrapper<Response>);Available on crate feature
hydrate only.Tuple Fields
0: SendWrapper<Response>Trait Implementations
Sourceimpl<E: FromServerFnError> ClientRes<E> for BrowserResponse
impl<E: FromServerFnError> ClientRes<E> for BrowserResponse
Sourcefn try_into_string(self) -> impl Future<Output = Result<String, E>> + Send
fn try_into_string(self) -> impl Future<Output = Result<String, E>> + Send
Attempts to extract a UTF-8 string from an HTTP response.
Sourcefn try_into_bytes(self) -> impl Future<Output = Result<Bytes, E>> + Send
fn try_into_bytes(self) -> impl Future<Output = Result<Bytes, E>> + Send
Attempts to extract a binary blob from an HTTP response.
Sourcefn try_into_stream(
self,
) -> Result<impl Stream<Item = Result<Bytes, Bytes>> + Send + Sync + 'static, E>
fn try_into_stream( self, ) -> Result<impl Stream<Item = Result<Bytes, Bytes>> + Send + Sync + 'static, E>
Attempts to extract a binary stream from an HTTP response.
Sourcefn status_text(&self) -> String
fn status_text(&self) -> String
Status text for the status code.
Sourcefn location(&self) -> String
fn location(&self) -> String
The
Location header or (if none is set), the URL of the response.Sourcefn has_redirect(&self) -> bool
fn has_redirect(&self) -> bool
Whether the response has the
REDIRECT_HEADER set.Auto Trait Implementations
impl Freeze for BrowserResponse
impl RefUnwindSafe for BrowserResponse
impl Send for BrowserResponse
impl Sync for BrowserResponse
impl Unpin for BrowserResponse
impl UnwindSafe for BrowserResponse