struct Paired<In, F: ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>>> {
sfn: F,
url: String,
}Available on crate feature
hydrate only.Fields
sfn: Furl: StringTrait Implementations
Sourceimpl<In: Encoding, Err: Send + Sync + FromServerFnError, F: ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>, Error = Err, InputStreamError = Err, OutputStreamError = Err> + FromReq<In, BrowserMockReq, Err>> FromReq<EncodingWrap<In>, BrowserMockReq, Err> for Paired<In, F>
impl<In: Encoding, Err: Send + Sync + FromServerFnError, F: ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>, Error = Err, InputStreamError = Err, OutputStreamError = Err> + FromReq<In, BrowserMockReq, Err>> FromReq<EncodingWrap<In>, BrowserMockReq, Err> for Paired<In, F>
Sourceimpl<In: Encoding, Err: Send + Sync + FromServerFnError, F: ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>, Error = Err, InputStreamError = Err, OutputStreamError = Err> + IntoReq<In, BrowserRequest, Err>> IntoReq<EncodingWrap<In>, BrowserRequest, Err> for Paired<In, F>
impl<In: Encoding, Err: Send + Sync + FromServerFnError, F: ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>, Error = Err, InputStreamError = Err, OutputStreamError = Err> + IntoReq<In, BrowserRequest, Err>> IntoReq<EncodingWrap<In>, BrowserRequest, Err> for Paired<In, F>
Sourceimpl<In: Encoding, Err: Send + Sync + FromServerFnError, F> ServerFn for Paired<In, F>where
F: FromReq<In, BrowserMockReq, Err> + IntoReq<In, BrowserRequest, Err> + Serialize + DeserializeOwned + Debug + Clone + Send + Sync + for<'de> Deserialize<'de> + ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>, Error = Err, InputStreamError = Err, OutputStreamError = Err>,
F::Output: IntoRes<Json, BrowserMockRes, Err> + FromRes<Json, BrowserResponse, Err> + Send + for<'de> Deserialize<'de>,
impl<In: Encoding, Err: Send + Sync + FromServerFnError, F> ServerFn for Paired<In, F>where
F: FromReq<In, BrowserMockReq, Err> + IntoReq<In, BrowserRequest, Err> + Serialize + DeserializeOwned + Debug + Clone + Send + Sync + for<'de> Deserialize<'de> + ServerFn<Client = BrowserClient, Server = BrowserMockServer, Protocol = Http<In, Json>, Error = Err, InputStreamError = Err, OutputStreamError = Err>,
F::Output: IntoRes<Json, BrowserMockRes, Err> + FromRes<Json, BrowserResponse, Err> + Send + for<'de> Deserialize<'de>,
Sourceconst PATH: &'static str = F::PATH
const PATH: &'static str = F::PATH
A unique path for the server function’s API endpoint, relative to the host, including its prefix.
Sourcetype Client = ClientWrap
type Client = ClientWrap
The type of the HTTP client that will send the request from the client side. Read more
Sourcetype Server = <F as ServerFn>::Server
type Server = <F as ServerFn>::Server
The type of the HTTP server that will send the response from the server side. Read more
Sourcetype Protocol = Http<EncodingWrap<In>, Post<JsonEncoding>>
type Protocol = Http<EncodingWrap<In>, Post<JsonEncoding>>
The protocol the server function uses to communicate with the client.
Sourcetype Error = Err
type Error = Err
The type of error in the server function return.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcetype InputStreamError = Err
type InputStreamError = Err
The type of error in the server function for stream items sent from the client to the server.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcetype OutputStreamError = Err
type OutputStreamError = Err
The type of error in the server function for stream items sent from the server to the client.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].Sourcefn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
fn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
Middleware that should be applied to this server function.